@@ -8,15 +8,10 @@ class OpenvinoPredict(object):
         self.core = Core()
         self.model = self.core.read_model(model=model)
         self.compiled_model = self.core.compile_model(model=self.model, device_name=device)
-        self.input_keys = self.compiled_model.inputs
         self.output_keys = self.compiled_model.outputs
 
     def predict(self, inputs: list) -> list:
-        input_dict = {}
-        for input in zip(self.input_keys, inputs):
-            input_dict[input[0]] = input[1]
-
-        results = self.compiled_model(input_dict)
+        results = self.compiled_model(inputs)
 
         outputs = []
         for output_key in self.output_keys:
